import configparser
import sys
import os

from merkava import blueprints
from sanic import Sanic


# from aoiklivereload import LiveReloader
# try:
#     reloader = LiveReloader()
#     reloader.start_watcher_thread()
# except Exception:
#     pass


service = Sanic()
service.blueprint(blueprints.bp)


@service.listener('before_server_start')
async def get_config(app, loop):
    if len(sys.argv) > 1:
        path = sys.argv[1]
        if os.path.isfile(path):
            config = configparser.ConfigParser()
            config.read(path)
            app.config.update(config['Storage'])


if __name__ == '__main__':
    service.run(host="127.0.0.1", port=6363)



__author__ = 'Adam Hopkins'
__email__ = 'admhpkns@gmail.com'
__version__ = '0.2.0'

from . import server, channels, views, blueprints

__all__ = [
    'server',
    'channels',
    'views',
    'blueprints',
]



"""
Tests for `merkava` module.
"""

import merkava
import os


# raise Exception(merkava)

service = merkava.server.service
path = os.path.join(os.path.dirname(os.path.abspath(__file__)), 'data')
channel_name = 'text_channel'


class TestMerkava(object):

    @classmethod
    def setup_class(cls):
        service.config.update({
            'path': path
        })

        folder = service.config.get('path')
        if os.path.exists(folder):
            for file in os.listdir(folder):
                file_path = os.path.join(folder, file)
                if os.path.isfile(file_path):
                    os.unlink(file_path)

    def url(self, *args):
        url = os.path.join('/', 'v1', 'text_channel', *args)
        print(url)
        return url

    def test_channel_create_index(self):
        request, response = service.test_client.get(self.url('9999'))
        file_path = os.path.join(path, '{}.mrkv'.format(channel_name))
        assert os.path.exists(file_path)
        assert os.path.isfile(file_path)

    def test_retrieve_not_exists(self):
        request, response = service.test_client.get(self.url('9999'))
        assert response.json is None
        assert response.status == 404

    @classmethod
    def teardown_class(cls):
        pass
